@@ -20,13 +20,14 @@
 #ifndef GMAIL_H
 #define GMAIL_H
 
-#include <qobject.h>
-#include <qstring.h>
+#include <QObject>
+#include <QString>
 #include <kurl.h>
 
 #include "gmailwalletmanager.h"
 
 namespace KIO { class Job; }
+class KJob;
 
 class QTimer;
 class QMutex;
@@ -39,10 +40,10 @@ class GMail : public QObject
 {
 	Q_OBJECT
 public:
-	GMail();
+	GMail(QObject* parent = 0);
 	virtual ~GMail();
 
-	void checkLoginParams();
+	void checkLoginParams(bool passwordChanged);
 	void setInterval(unsigned int i);
 	void setInterval(unsigned int i, bool forceStart);
 
@@ -65,8 +66,11 @@ protected:
 	
 	void dump2File(const QString filename,const QString data);
 	
-	bool cookieExists(QString cookieName, QString url);
-	bool cookieExists(QString cookieName);
+	bool cookieExists(QString, QString);
+	bool cookieExists(QString);
+	bool areCookiesAllowed(QString);
+	QString getDomainAdvice(QString);
+	bool setDomainAdvice(QString, QString);
 
 private:
 	unsigned int mInterval;
@@ -97,13 +101,18 @@ private:
 	QTimer *mTimer;
 	
 	//Normal GMail
-	QString gGMailLoginURL, gGMailLoginPOSTFormat, gGMailCheckURL, gGMailLogOut;
+	QString gGMailLoginURL, gGMailAuthURL, gGMailLoginPOSTFormat, gGMailCheckURL, gGMailLogOut;
 
 	//GAP4D: Google Applications for Domains
-	QString gGAP4DLoginURL, gGAP4DLoginPOSTFormat, gGAP4DCheckURL, gGAP4DLogOut;
+	QString gGAP4DLoginURL, gGAP4DAuthURL, gGAP4DLoginPOSTFormat, gGAP4DCheckURL, gGAP4DLogOut;
 
-	KURL loginRedirection;
+	KUrl loginRedirection;
+
+	class Private;
+	Private* d;
 	
+	QString findGALXCookie();
+
 public slots:
 	void slotCheckGmail();
 	void slotGetWalletPassword(const QString&);
@@ -111,16 +120,16 @@ public slots:
 	void slotLogOut();
 
 protected slots:
-	void slotLoginResult(KIO::Job*);
+	void slotLoginResult(KJob*);
 	void slotLoginData(KIO::Job*, const QByteArray&);
-	void slotLoginRedirection(KIO::Job *job, const KURL &url);
+	void slotLoginRedirection(KIO::Job *job, const KUrl &url);
 
-	void slotPostLoginResult(KIO::Job*);
+	void slotPostLoginResult(KJob*);
 	void slotPostLoginData(KIO::Job*, const QByteArray&);
 
 	void slotTimeout();
 
-	void slotCheckResult(KIO::Job*);
+	void slotCheckResult(KJob*);
 	void slotCheckData(KIO::Job*, const QByteArray&);
 	
 private slots:
@@ -128,13 +137,13 @@ private slots:
 
 signals:
 	void loginStart();
-	void loginDone(bool success, bool spawnedFromTimer, const QString &why = QString::null);
+	void loginDone(bool success, bool spawnedFromTimer, const QString &why = QString());
+	void loggedOut();
 
 	void checkStart();
 	void checkDone(const QString &data);
 	
 	void sessionChanged();
-	void logingOut();
 };
 
 #endif
