@@ -19,14 +19,16 @@
  ***************************************************************************/
 
 // define this symbol if you want to try to detect the language of your account
-#define DETECT_GLANGUAGE
+#undef DETECT_GLANGUAGE
 
 #include "gmailparser.h"
 #include "gmail_constants.h"
 #include "prefs.h"
 
 #include <kdebug.h>
-#include <qregexp.h>
+#include <QRegExp>
+//Added by qt3to4:
+#include <QList>
 #include <klocale.h>
 #include <kcharsets.h>
 
@@ -36,8 +38,8 @@
  * This class parses the resulting data of a call to
  * Gmail's JavaScript interface.
 */
-GMailParser::GMailParser() :
-		QObject(0, "GMailParser"),
+GMailParser::GMailParser(QObject* parent) :
+		QObject(parent),
 		mInvites(0)
 {
 	mSummary.inbox = 0;
@@ -57,6 +59,7 @@ GMailParser::GMailParser() :
 	gGMailVersion.append("1x4nkpwjfkc8x");
 	gGMailVersion.append("1ddh9n6glzd1c");
 	gGMailVersion.append("11qm1wldxu1ww");
+	gGMailVersion.append("5vnvxev1uvtq");
 
 	// TODO: read this from a file
 #ifdef DETECT_GLANGUAGE
@@ -121,43 +124,45 @@ GMailParser::~GMailParser()
  *
  * @param _data Gmail's JavaScript response
 */
-void GMailParser::parse(const QString &_data)
+void GMailParser::parse(const QString &data)
 {
 	static QRegExp rx("D\\(\\[(.*)\\][\\s\\n]*\\);");
 	int pos = 0;
-	unsigned int oldNewCount, NewCount = 0;
 
 	rx.setMinimal(true);
 
 	if(!rx.isValid()) {
-		kdWarning() << k_funcinfo << "Invalid RX!\n"
+		kWarning() << k_funcinfo << "Invalid RX!\n"
 			<< rx.errorString() << endl;
 	} 
 
 	mCurMsgId = 0;
-	oldNewCount = getNewCount();
+
 	QMap<QString,bool> *oldMap = getThreadList();
 	freeThreadList();
 	
 	if(oldMap) {
-		kdDebug() << k_funcinfo << "oldmap.size=" << oldMap->size() << endl;
+		kDebug() << k_funcinfo << "oldmap.size=" << oldMap->size();
 		if (oldMap->begin().key() > previousLatestThread) {
 			previousLatestThread = oldMap->begin().key();
 		}
 	} else {
-		kdDebug() << k_funcinfo << "no oldmap" << endl;
+		kDebug() << k_funcinfo << "no oldmap";
 	}
 	
-	kdDebug() << k_funcinfo << "previousLatestThread=" << previousLatestThread << endl;
+	kDebug() << k_funcinfo << "previousLatestThread=" << previousLatestThread;
 
-	QString data = QString::fromUtf8(_data);
 
-	while((pos = rx.search(data, pos)) != -1) {
+	/*
+	 * mailsArrived refers to new messages in the parsed threads
+	 */
+	unsigned int arrivedMails = 0;
+	while((pos = rx.indexIn(data, pos)) != -1) {
 		QString str = rx.cap(1);
 		QRegExp rxType("^\"([a-z]+)\",");
 
 		int tokPos = -1;
-		if((tokPos = rxType.search(str)) >= 0) {
+		if((tokPos = rxType.indexIn(str)) >= 0) {
 			QString tok = rxType.cap(1);
 			int tokLen = rxType.matchedLength();
 
@@ -165,7 +170,7 @@ void GMailParser::parse(const QString &_data)
 			str.remove(tokPos, tokLen);
 			
 			if(tok == D_THREAD) {
-				NewCount += parseThread(str, oldMap);
+				arrivedMails += parseThread(str, oldMap);
 			} else if(tok == D_VERSION) {
 				parseVersion(str);
 			} else if(tok == D_QUOTA) {
@@ -190,19 +195,7 @@ void GMailParser::parse(const QString &_data)
 	delete oldMap;
 	oldMap = 0;
 
-	kdDebug() << k_funcinfo << "NewCount=" << NewCount << endl;
-	kdDebug() << k_funcinfo << "oldNewCount=" << oldNewCount << endl;
-	
-	int realCount = getNewCount(true);
-	if (oldNewCount == 0 && realCount != 0)
-		NewCount = realCount;
-	
-	if(NewCount > 0)
-		emit mailArrived(NewCount);
-	if(oldNewCount != NewCount)
-		emit mailCountChanged();
-	if(realCount == 0)
-		emit noUnreadMail();
+	emit countUpdate(arrivedMails);
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -225,7 +218,7 @@ uint GMailParser::parseThread(const QString &_data, const QMap<QString,bool>* ol
 	static QRegExp rx(
 			"\\[\"([a-fA-F0-9]+)\"\\s*,"	// replyID
 			"\\s*([0-9]+)\\s*,"		// isNew
-			"\\s*([0-9]+)\\s*,"		// unknown1
+			"\\s*([0-9]+)\\s*,"		// isStarred
 			"\\s*\"([^\"]*)\"\\s*,"		// date_short
 			"\\s*\"([^\"]*)\"\\s*,"		// senders
 			"\\s*\"([^\"]*)\"\\s*,"		// chevron
@@ -245,7 +238,7 @@ uint GMailParser::parseThread(const QString &_data, const QMap<QString,bool>* ol
 	static QRegExp rx2(
 			"\\[\"([a-fA-F0-9]+)\"\\s*,"	// replyID
 			"\\s*([0-9]+)\\s*,"		// isNew
-			"\\s*([0-9]+)\\s*,"		// unknown1
+			"\\s*([0-9]+)\\s*,"		// isStarred
 			"\\s*\"([^\"]*)\"\\s*,"		// date_short
 			"\\s*\"([^\"]*)\"\\s*,"		// senders
 			"\\s*\"([^\"]*)\"\\s*,"		// chevron
@@ -270,12 +263,12 @@ uint GMailParser::parseThread(const QString &_data, const QMap<QString,bool>* ol
 	rx2.setMinimal(true);
 
 	if(!rx.isValid()) {
-		kdWarning() << k_funcinfo << "Invalid RX!\n"
+		kWarning() << k_funcinfo << "Invalid RX!\n"
 				<< rx.errorString() << endl;
 	}
 
 	if(!rx2.isValid()) {
-		kdWarning() << k_funcinfo << "Invalid RX2!\n"
+		kWarning() << k_funcinfo << "Invalid RX2!\n"
 				<< rx2.errorString() << endl;
 	}
 	
@@ -286,19 +279,19 @@ uint GMailParser::parseThread(const QString &_data, const QMap<QString,bool>* ol
 
 	unsigned int newMsgCount = 0;
 
-	while((pos = rx.search(data, pos)) != -1) {
+	while((pos = rx.indexIn(data, pos)) != -1) {
 		Thread *t = new Thread;
 		t->id = mCurMsgId ++;
 		t->replyId = rx.cap(1);
 		t->isNew = rx.cap(2).toInt();
-		t->unknown1 = rx.cap(3).toUInt();
+		t->isStarred = rx.cap(3).toInt();
 		t->date_short = rx.cap(4);
 		t->senders = cleanUpData(rx.cap(5));
 		t->chevron = rx.cap(6);
 		t->subject = cleanUpData(rx.cap(7));
 		t->snippet = cleanUpData(rx.cap(8));
 		t->labels = rx.cap(9);
-		t->attachments = QStringList::split(",", rx.cap(10));
+		t->attachments = rx.cap(10).split(",", QString::SkipEmptyParts);
 		t->msgId = rx.cap(11);
 		t->unknown2 = rx.cap(12).toUInt();
 		t->date_long = rx.cap(13);
@@ -307,11 +300,14 @@ uint GMailParser::parseThread(const QString &_data, const QMap<QString,bool>* ol
 
 		if(t->isNew && (t->msgId > previousLatestThread || t->replyId > previousLatestThread) && (!oldMap || 
 				 (oldMap->find(t->msgId) == oldMap->end()))) {
-			kdDebug() << "Message [" << t->msgId << "] is new." << endl;
+			kDebug() << "Message [" << t->msgId << "] is new.";
+			t->isNew = true;
 			newMsgCount ++;
-		} else
-			kdDebug() << "Message [" << t->msgId << "] is NOT new." << endl;
-		
+		} else {
+			t->isNew = false;
+			kDebug() << "Message [" << t->msgId << "] is NOT new.";
+		}
+
 		// (re-)insert
 		mThreads.insert(t->msgId, t);
 
@@ -320,19 +316,19 @@ uint GMailParser::parseThread(const QString &_data, const QMap<QString,bool>* ol
 
 	pos = 0;
 	
-	while((pos = rx2.search(data, pos)) != -1) {
+	while((pos = rx2.indexIn(data, pos)) != -1) {
 		Thread *t = new Thread;
 		t->id = mCurMsgId ++;
 		t->replyId = rx2.cap(1);
 		t->isNew = rx2.cap(2).toInt();
-		t->unknown1 = rx2.cap(3).toUInt();
+		t->isStarred = rx2.cap(3).toInt();
 		t->date_short = rx2.cap(4);
 		t->senders = cleanUpData(rx2.cap(5));
 		t->chevron = rx2.cap(6);
 		t->subject = cleanUpData(rx2.cap(7));
 		t->snippet = cleanUpData(rx2.cap(8));
 		t->labels = rx2.cap(9);
-		t->attachments = QStringList::split(",", rx.cap(10));
+		t->attachments = rx.cap(10).split(",", QString::SkipEmptyParts);
 		t->msgId = rx2.cap(11);
 		t->unknown2 = rx2.cap(12).toUInt();
 		t->date_long = rx2.cap(13);
@@ -341,20 +337,23 @@ uint GMailParser::parseThread(const QString &_data, const QMap<QString,bool>* ol
 
 		if(t->isNew && (t->msgId > previousLatestThread || t->replyId > previousLatestThread) && (!oldMap || 
 				 (oldMap->find(t->msgId) == oldMap->end()))) {
-			kdDebug() << "Message [" << t->msgId << "] is new." << endl;
+			kDebug() << "Message [" << t->msgId << "] is new.";
+			t->isNew = true;
 			newMsgCount ++;
-		} else
-			kdDebug() << "Message [" << t->msgId << "] is NOT new." << endl;
-		
+		} else {
+			kDebug() << "Message [" << t->msgId << "] is NOT new.";
+			t->isNew = false;
+		}
+
 		// (re-)insert
 		mThreads.insert(t->msgId, t);
 
 		pos += rx2.matchedLength();
 	}
 
-	kdDebug() << k_funcinfo << "Finished searching for threads in: " << endl;
-	kdDebug() << data << endl;
-	kdDebug() << k_funcinfo << "newMsgCount: " << newMsgCount << endl;
+	kDebug() << k_funcinfo << "Finished searching for threads in: ";
+	kDebug() << data;
+	kDebug() << k_funcinfo << "newMsgCount: " << newMsgCount;
 
 	return newMsgCount;
 }
@@ -371,15 +370,15 @@ void GMailParser::parseVersion(const QString &_data)
 	QString data = _data;
 	data.remove('"');
 	
-	kdDebug() << k_funcinfo << "Version string: " << data << endl;
+	kDebug() << k_funcinfo << "Version string: " << data;
 	
-	QStringList list = QStringList::split(",",data);
+	QStringList list = data.split(",", QString::SkipEmptyParts);
 	if(list.size() != 5)
-		kdWarning() << k_funcinfo << "Wrong number of elements: "
+		kWarning() << k_funcinfo << "Wrong number of elements: "
 				<< list.size() << ", should be: 5." << endl;
 	
 	QStringList::Iterator iter = list.begin();
-	unsigned int i = 0;
+	int i = 0;
 	while(iter != list.end()) {
 		QString str = *iter;
 		switch(i) {
@@ -399,13 +398,13 @@ void GMailParser::parseVersion(const QString &_data)
 				mVersion.version = str;
 				break;
 			default:
-				kdWarning() << k_funcinfo << "Unknown version token: " << str << "(" << i <<")" << endl;
+				kWarning() << k_funcinfo << "Unknown version token: " << str << "(" << i <<")";
 				break;
 		}
 		iter++;
 		i++;
 	}
-	kdDebug() << "Gmail version " << mVersion.version << endl;
+	kDebug() << "Gmail version " << mVersion.version;
 	
 	bool ok = false;
 	
@@ -416,13 +415,13 @@ void GMailParser::parseVersion(const QString &_data)
 	
 #ifdef DETECT_GLANGUAGE
 	if(gGMailLanguageCode.contains(mVersion.language))
-		kdDebug() << "Gmail language: " << gGMailLanguageCode[mVersion.language] << endl;
+		kDebug() << "Gmail language: " << gGMailLanguageCode[mVersion.language];
 	else
-		kdWarning() << k_funcinfo << "Unknown language code: " << mVersion.language << endl;
+		kWarning() << k_funcinfo << "Unknown language code: " << mVersion.language;
 #endif
 	
 	if(!ok) {
-		kdWarning() << k_funcinfo << "Gmail version " << mVersion.version << " is not supported, check for updates!" << endl;
+		kWarning() << k_funcinfo << "Gmail version " << mVersion.version << " is not supported, check for updates!";
 		emit versionMismatch();
 	}
 }
@@ -437,7 +436,7 @@ void GMailParser::parseVersion(const QString &_data)
 */
 void GMailParser::parseQuota(const QString &data)
 {	
-	QStringList list = QStringList::split(",",data);
+	QStringList list = data.split(",", QString::SkipEmptyParts);
 	if(list.size() == 4 || list.size() == 9) {
 		QStringList::Iterator iter = list.begin();
 		unsigned int i = 0;
@@ -464,7 +463,7 @@ void GMailParser::parseQuota(const QString &data)
 			i++;
 		}
 	} else
-		kdWarning() << k_funcinfo << "Wrong number of elements in qu: "
+		kWarning() << k_funcinfo << "Wrong number of elements in qu: "
 			<< list.size() << ", should be 4 or 9." << endl;
 }
 
@@ -480,13 +479,13 @@ void GMailParser::parseDefaultSummary(const QString &_data)
 	static QRegExp rx("\"([a-z]+)\",([0-9]+)");
 
 	if(!rx.isValid()) {
-		kdWarning() << k_funcinfo << "Invalid RX!\n"
+		kWarning() << k_funcinfo << "Invalid RX!\n"
 			<< rx.errorString() << endl;
 	}
 	QString data = _data;
 	int pos = 0;
 
-	while((pos = rx.search(data, pos)) != -1) {
+	while((pos = rx.indexIn(data, pos)) != -1) {
 		QString str_name = rx.cap(1), str_val = rx.cap(2);
 		int val = str_val.toUInt();
 
@@ -496,11 +495,11 @@ void GMailParser::parseDefaultSummary(const QString &_data)
 			mSummary.drafts = val;
 		else if( QString::compare(str_name,"spam") == 0)
 			mSummary.spam = val;
-		else kdWarning() << k_funcinfo << "unkown identifier " << str_name << endl;
+		else kWarning() << k_funcinfo << "unknown identifier " << str_name;
 
 		pos += rx.matchedLength();
 	}
-	kdDebug() << k_funcinfo << endl  
+	kDebug() << k_funcinfo << endl  
 		<< "inbox=" << mSummary.inbox << "\n"
 		<< "drafts=" << mSummary.drafts << "\n"
 		<< "spam=" << mSummary.spam << "\n" << endl;
@@ -522,7 +521,7 @@ void GMailParser::parseLabel(const QString &data)
 		);
 
 	if(!rx.isValid()) {
-		kdWarning() << k_funcinfo << "Invalid RX!\n"
+		kWarning() << k_funcinfo << "Invalid RX!\n"
 			<< rx.errorString() << endl;
 	}
 	int pos = 0;
@@ -530,16 +529,16 @@ void GMailParser::parseLabel(const QString &data)
 	mLabels.clear();
 	eLabels.clear();
 	
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 
-	while((pos = rx.search(data, pos)) != -1) {
+	while((pos = rx.indexIn(data, pos)) != -1) {
 		mLabels.insert(rx.cap(1), rx.cap(2).toUInt());
 		
 		QString k = rx.cap(1);
 		k.replace(" ", "-");
 		eLabels.insert(k, rx.cap(1));
 		
-		kdDebug() << rx.cap(1) << " has " << rx.cap(2) << " unread messages" << endl;
+		kDebug() << rx.cap(1) << " has " << rx.cap(2) << " unread messages";
 		pos += rx.matchedLength();
 	}
 }
@@ -558,7 +557,7 @@ void GMailParser::parseInvite(const QString &data)
 	if(!ok) {
 		mInvites = 0;
 	}
-	kdDebug() << k_funcinfo << "Invites=" << mInvites << endl;
+	kDebug() << k_funcinfo << "Invites=" << mInvites;
 }
 
 /**
@@ -576,7 +575,7 @@ void GMailParser::parseGName(const QString &data)
 	
 	if(newName != gName) {
 		gName = newName;
-		kdDebug() << "Gaia name: " << gName << endl;
+		kDebug() << "Gaia name: " << gName;
 		emit gNameUpdate(gName);
 	}
 }
@@ -597,8 +596,8 @@ QMap<QString, bool> *GMailParser::getThreadList() const
 	if(!mThreads.isEmpty()) {
 		ret = new QMap<QString, bool>();
 
-		QValueList<QString> klist = mThreads.keys();
-		QValueList<QString>::iterator iter = klist.begin();
+		QList<QString> klist = mThreads.keys();
+		QList<QString>::iterator iter = klist.begin();
 
 		while(iter != klist.end()) {
 			Thread *t = mThreads[*iter];
@@ -654,23 +653,25 @@ const GMailParser::Thread& GMailParser::getThread(int id) const
 }
 
 /**
- * Return the thread information of last thread in the map
+ * Return the thread information of last arrived thread in the map
  *
  * @return A copy of the Thread
  */
-const GMailParser::Thread& GMailParser::getLastThread() const
+const GMailParser::Thread& GMailParser::getLastArrivedThread() const
 {
 	static Thread nullThread;
 
 	QMap<QString, Thread*>::const_iterator iter = mThreads.constEnd();
-	
-	iter--;
-	
-	if(iter == mThreads.end()) {
-		nullThread.isNull = true;
-		return nullThread;
-	} else
-		return *(*iter);
+	QMap<QString, Thread*>::const_iterator begin = mThreads.constBegin();
+
+	while (iter != begin) {
+		--iter;
+		if ((*iter)->isNew)
+			return *(*iter);
+	}
+
+	nullThread.isNull = true;
+	return nullThread;
 }
 
 const QString GMailParser::getGaiaName() const
@@ -681,18 +682,18 @@ const QString GMailParser::getGaiaName() const
 /**
  * Retrieve the number of unread messages.
  *
- * If realCount is false the box parameter is ignored.
+ * If mode is ParsedOnlyCount the box parameter is ignored.
  *
- * @param realCount If the number of unread messages should be taken from the totals or only from the parsed messages
+ * @param mode If the number of unread messages should be taken from the totals or only from the parsed messages
  * @param box The name of the box (inbox, drafts, spam; or in the future: label) from where the real number of unread messages should be taken from
  * @return The number of unread messages
- * @example getNewCount(true,"inbox") Get the real number of unread messages in the inbox
+ * @example unread(GMailParser::TotalCount,"inbox") Get the real number of unread messages in the inbox
 */
-unsigned int GMailParser::getNewCount(bool realCount, QString box) const
+unsigned int GMailParser::unread(CountMode mode, QString box) const
 {
 	unsigned int ret = 0;
 	
-	if(realCount == true) {
+	if(mode == TotalCount) {
 		if(box.compare("inbox") == 0)
 			return mSummary.inbox;
 		else if(box.compare("drafts") == 0)
@@ -703,7 +704,7 @@ unsigned int GMailParser::getNewCount(bool realCount, QString box) const
 			if (mLabels.contains(box))
 				return mLabels[box];
 		}
-		kdWarning() << k_funcinfo << "The box " << box << " doesn't exist! returning value as if realCount=false" << endl;
+		kWarning() << k_funcinfo << "The box " << box << " doesn't exist! returning value as if mode=ParsedOnlyCount";
 	}
 	
 	QMap<QString, bool> *lst = getThreadList();
@@ -717,68 +718,59 @@ unsigned int GMailParser::getNewCount(bool realCount, QString box) const
 			iter ++;
 		}
 	}
-
+	
 	delete lst;
 	lst = 0;
-	
+
 	return ret;
 }
 
 /**
  * Retrieve the number of unread messages.
  *
- * @param realCount If the number of unread messages should be taken from the totals or only from the parsed messages
+ * @param mode If the number of unread messages should be taken from the totals or only from the parsed messages
  * @return The number of unread messages
 */
-unsigned int GMailParser::getNewCount(bool realCount) const
+unsigned int GMailParser::unread(CountMode mode) const
 {
 	static QRegExp rx ("in:([^ ]+)");
 	static QRegExp rx2("label:([^ ]+)");
 	QString box;
+	
 	int pos;
-
-	if (realCount) {
-		if (rx.search(Prefs::searchFor()) == -1 && rx2.search(Prefs::searchFor()) == -1) {
+	if (mode == TotalCount) {
+		if (rx.indexIn(Prefs::searchFor()) == -1 && rx2.indexIn(Prefs::searchFor()) == -1) {
 			// If none are specified gmail will return any unread mail (except spam and drafts)
 			// TODO: to fix this we need to count all messages (!drafts,!spam, inbox + labels)
-			realCount = false;
+			mode = ParsedOnlyCount;
 			//box = "inbox";
-		} else if (rx.search(Prefs::searchFor()) != -1 && rx2.search(Prefs::searchFor()) != -1) {
+		} else if (rx.indexIn(Prefs::searchFor()) != -1 && rx2.indexIn(Prefs::searchFor()) != -1) {
 			//there's no other way to know how many emails are in:inbox and in specified label:LABEL
-			realCount = false;
-		} else if ((pos = rx.search(Prefs::searchFor())) != -1) {
+			mode = ParsedOnlyCount;
+		} else if ((pos = rx.indexIn(Prefs::searchFor())) != -1) {
 			box = rx.cap(1);
 
 			pos += rx.matchedLength();
 			// make sure there is only one in: in the search string
-			if (rx.search(Prefs::searchFor(), pos) != -1) {
-				realCount = false;
+			if (rx.indexIn(Prefs::searchFor(), pos) != -1) {
+				mode = ParsedOnlyCount;
 			}
-		} else if ((pos = rx2.search(Prefs::searchFor())) != -1) {
+		} else if ((pos = rx2.indexIn(Prefs::searchFor())) != -1) {
 			box = rx2.cap(1);
 
 			pos += rx2.matchedLength();
 			// make sure there is only one label: in the search string
-			if (rx2.search(Prefs::searchFor(), pos) != -1) {
-				realCount = false;
+			if (rx2.indexIn(Prefs::searchFor(), pos) != -1) {
+				mode = ParsedOnlyCount;
 			} else if (eLabels.contains(box)) {
 				box = eLabels[box];
 			}
 		}
 	}
 	
-	return getNewCount(realCount, box);
+	return unread(mode, box);
 }
 
-/**
- * Retrieve the number of unread messages.
- *
- * @return The number of unread messages that were parsed
-*/
-unsigned int GMailParser::getNewCount() const
-{
-	return getNewCount(false);
-}
 
 ///////////////////////////////////////////////////////////////////////////
 // Clean up functions
@@ -788,8 +780,8 @@ void GMailParser::freeThreadList()
 {
 	if(!mThreads.isEmpty()) {
 
-		QValueList<QString> klist = mThreads.keys();
-		QValueList<QString>::iterator iter = klist.begin();
+		QList<QString> klist = mThreads.keys();
+		QList<QString>::iterator iter = klist.begin();
 
 		while(iter != klist.end()) {
 			Thread *t = mThreads[*iter];
@@ -815,7 +807,7 @@ QString GMailParser::stripTags(QString data)
 	static QRegExp tags("<[^>]+>|</[^>]+>|<[^>]+/>");
 	
 	if(!tags.isValid()) {
-		kdWarning() << k_funcinfo << "Invalid RX!\n"
+		kWarning() << k_funcinfo << "Invalid RX!\n"
 				<< tags.errorString() << endl;
 	}
 	
@@ -839,11 +831,11 @@ QString GMailParser::convertEntities(QString data)
 	static QRegExp format("\\\\((u)([0-9a-zA-Z]{4})|(x)([0-9a-zA-Z]{2}))");
 	
 	if(!format.isValid()) {
-		kdWarning() << k_funcinfo << "Invalid RX!\n"
+		kWarning() << k_funcinfo << "Invalid RX!\n"
 				<< format.errorString() << endl;
 	}
 	
-	while(format.search(data) != -1) {
+	while(format.indexIn(data) != -1) {
 		id = format.cap(2);
 		found = format.cap(3);
 		if (found.length() == 0) {
@@ -875,3 +867,4 @@ QString GMailParser::cleanUpData(QString data)
 	return data;
 }
 
+#include "gmailparser.moc"
