@@ -4,7 +4,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
-#include <kmdcodec.h>
+#include <kcodecs.h>
 
 
 GMailWalletManager *GMailWalletManager::mInstance = 0;
@@ -18,6 +18,7 @@ GMailWalletManager::GMailWalletManager()
 GMailWalletManager::~GMailWalletManager()
 {
 	delete mWallet;
+	mWallet = 0;
 }
 
 GMailWalletManager *GMailWalletManager::instance()
@@ -30,9 +31,9 @@ GMailWalletManager *GMailWalletManager::instance()
 bool GMailWalletManager::set(const QString &p)
 {
 	bool ret = true;
-	KMD5 md5(p);
+	KMD5 md5(p.toUtf8());
 		
-	kdDebug() << k_funcinfo << "Password=" << p.length()
+	kDebug() << k_funcinfo << "Password=" << p.length()
 			 << " hash=" << md5.hexDigest() << endl;
 	
 	mHash = md5.hexDigest();
@@ -40,12 +41,12 @@ bool GMailWalletManager::set(const QString &p)
 	mPassword = p;
 
 	if(Prefs::passwordFromWallet()) {
-		kdDebug() << k_funcinfo << "PasswordFromWallet" << endl;
+		kDebug() << k_funcinfo << "PasswordFromWallet";
 		Prefs::setGmailPassword("");
 		Prefs::self()->writeConfig();
 		ret = storeWallet();
 	} else {
-		kdDebug() << k_funcinfo << "PasswordFromKConfig" << endl;
+		kDebug() << k_funcinfo << "PasswordFromKConfig";
 		ret = storeKConfig();
 	}
 
@@ -56,35 +57,35 @@ bool GMailWalletManager::get()
 {
 	bool ret = true;
 
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 
 	if(Prefs::passwordFromWallet()) {
-		kdDebug() << k_funcinfo << "yeah, from wallet" << endl;
+		kDebug() << k_funcinfo << "yeah, from wallet";
 		
 		Prefs::setGmailPassword("");
 		Prefs::self()->writeConfig();
 		if(mWallet) {
-			kdDebug() << k_funcinfo << "wallet exists" << endl;
+			kDebug() << k_funcinfo << "wallet exists";
 			if(mWallet->isOpen()) {
-				kdDebug() << k_funcinfo << "wallet open" << endl;
+				kDebug() << k_funcinfo << "wallet open";
 				QString ret;
 				mWallet->readPassword("gmailPassword", ret);
-				kdDebug() << k_funcinfo << "Got password" << endl;
-				KMD5 md5(ret);
+				kDebug() << k_funcinfo << "Got password";
+				KMD5 md5(ret.toUtf8());
 				mHash = md5.hexDigest();
 				emit getWalletPassword(ret);
 			}
 		} else {
-			kdDebug() << k_funcinfo << "wallet NOT open, callback" << endl;
+			kDebug() << k_funcinfo << "wallet NOT open, callback";
 			ret = getWallet();
 		}
 	} else {
-		kdDebug() << k_funcinfo << "from kconfig" << endl;
+		kDebug() << k_funcinfo << "from kconfig";
 		ret = getKConfig();
 	}
 
 
-	kdDebug() << k_funcinfo << "return " << ret << endl;
+	kDebug() << k_funcinfo << "return " << ret;
 	
 	return ret;
 
@@ -93,14 +94,14 @@ bool GMailWalletManager::get()
 void GMailWalletManager::openWallet()
 {
 	if(!mWallet) {
-		kdDebug() << k_funcinfo << "calling openWallet" << endl;
+		kDebug() << k_funcinfo << "calling openWallet";
 		mWallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(),
 		                    0, KWallet::Wallet::Asynchronous);
 		if(!mWallet)
 			KMessageBox::error(0, i18n("KCheckGMail could not open "
 				"the wallet. Please check your preferences."));
 		else {
-			kdDebug() << k_funcinfo << "connecting wallet" << endl;
+			kDebug() << k_funcinfo << "connecting wallet";
 			connect(mWallet, SIGNAL(walletOpened(bool)), SLOT(slotWalletChangedStatus()));
 		}
 	}
@@ -109,20 +110,20 @@ void GMailWalletManager::openWallet()
 // Kopete is a strong influence here. Cheers to those guys!
 void GMailWalletManager::slotWalletChangedStatus()
 {
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 
 	if(!mWallet)
-		kdDebug() << k_funcinfo << "status changed but mWallet == 0" << endl;
+		kDebug() << k_funcinfo << "status changed but mWallet == 0";
 	else
 	if(mWallet->isOpen()) {
-		kdDebug() << k_funcinfo << "Wallet Open!" << endl;
-		if(!mWallet->hasFolder(QString::fromLatin1("KCheckGmail"))) {
-			kdDebug() << k_funcinfo << "Creating folder" << endl;
-			mWallet->createFolder(QString::fromLatin1("KCheckGmail"));
+		kDebug() << k_funcinfo << "Wallet Open!";
+		if(!mWallet->hasFolder(QLatin1String("KCheckGmail"))) {
+			kDebug() << k_funcinfo << "Creating folder";
+			mWallet->createFolder(QLatin1String("KCheckGmail"));
 		}
 
-		if(mWallet->setFolder(QString::fromLatin1("KCheckGmail"))) {
-			kdDebug() << k_funcinfo << "Setting folder" << endl;
+		if(mWallet->setFolder(QLatin1String("KCheckGmail"))) {
+			kDebug() << k_funcinfo << "Setting folder";
 			// success!
 			QObject::connect(mWallet, SIGNAL(walletClosed()), 
 				this, SLOT(slotCloseWallet()));
@@ -135,22 +136,22 @@ void GMailWalletManager::slotWalletChangedStatus()
 
 			QString ret;
 			mWallet->readPassword("gmailPassword", ret);
-			kdDebug() << k_funcinfo << "Got pass: " << ret << endl;
-			KMD5 md5(ret);
+			kDebug() << k_funcinfo << "Got pass: " << ret;
+			KMD5 md5(ret.toUtf8());
 			mHash = md5.hexDigest();
 			emit getWalletPassword(ret);
 			clearPassword();
 
 		} else {
 			// opened OK, but we can't use it
-			kdDebug() << k_funcinfo << "Could not set folder" << endl;
+			kDebug() << k_funcinfo << "Could not set folder";
 			delete mWallet;
 			mWallet = 0;
 		}
 
 
 	} else {
-		kdDebug() << k_funcinfo << "Wallet not open!" << endl;
+		kDebug() << k_funcinfo << "Wallet not open!";
 		delete mWallet;
 		mWallet = 0;
 	}
@@ -165,16 +166,16 @@ void GMailWalletManager::slotCloseWallet()
 bool GMailWalletManager::storeWallet()
 {
 	bool ret = true;
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 
 	if(KWallet::Wallet::isEnabled()) {
 		if(mWallet && mWallet->isOpen()) {
-			kdDebug() << k_funcinfo << "Wallet open. Setting immediately." << endl;
+			kDebug() << k_funcinfo << "Wallet open. Setting immediately.";
 			mWallet->writePassword("gmailPassword", mPassword);
 			clearPassword();
 			emit setWalletPassword(true);
 		} else {
-			kdDebug() << k_funcinfo << "Wallet Not Open.." << endl;
+			kDebug() << k_funcinfo << "Wallet Not Open..";
 			openWallet();
 		}
 	} else {
@@ -183,6 +184,7 @@ bool GMailWalletManager::storeWallet()
 			"Do you want to save the password in the unsafe configuration file instead?"),
 			i18n("Unable to store secure password"),
 			KGuiItem(i18n("Store unsafe"), "unlock"),
+			KStandardGuiItem::cancel(),
 			"FallbackToKConfig") != KMessageBox::Continue) {
 			ret = false;
 		} else {
@@ -197,7 +199,7 @@ bool GMailWalletManager::storeWallet()
 bool GMailWalletManager::storeKConfig()
 {
 	bool ret = true;
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 	Prefs::setGmailPassword(mPassword);
 	Prefs::self()->writeConfig();
 	clearPassword();
@@ -208,18 +210,18 @@ bool GMailWalletManager::storeKConfig()
 bool GMailWalletManager::getWallet()
 {
 	bool ret = true;
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 
 	if(KWallet::Wallet::isEnabled()) {
-		kdDebug() << k_funcinfo << "it's enabled" << endl;
+		kDebug() << k_funcinfo << "it's enabled";
 		// just have to rely on not calling this method twice for now. No checks
 		// are in place.
 		if(mWallet && mWallet->isOpen()) {
-			kdDebug() << k_funcinfo << "Wallet open." << endl;
+			kDebug() << k_funcinfo << "Wallet open.";
 			QString p;
 			mWallet->readPassword("gmailPassword", p);
-			kdDebug() << k_funcinfo << "p=" << p << endl;
-			KMD5 md5(p);
+			kDebug() << k_funcinfo << "p=" << p;
+			KMD5 md5(p.toUtf8());
 			mHash = md5.hexDigest();
 			emit getWalletPassword(p);
 		} else
@@ -230,12 +232,13 @@ bool GMailWalletManager::getWallet()
 			"Do you want to save the password in the unsafe configuration file instead?"),
 			i18n("Unable to retrieve secure password"),
 			KGuiItem(i18n("Store unsafe"), "unlock"),
+			KStandardGuiItem::cancel(),
 			"FallbackToKConfig") != KMessageBox::Continue) {
 			ret = false;
 		} else
 			ret = getKConfig();
 		
-		kdDebug() << k_funcinfo << "Returned from getKConfig()" << endl;
+		kDebug() << k_funcinfo << "Returned from getKConfig()";
 		
 	}
 	return ret;
@@ -244,9 +247,9 @@ bool GMailWalletManager::getWallet()
 bool GMailWalletManager::getKConfig()
 {
 	bool ret = true;
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 
-	KMD5 md5(Prefs::gmailPassword());
+	KMD5 md5(Prefs::gmailPassword().toUtf8());
 	mHash = md5.hexDigest();
 	emit getWalletPassword(Prefs::gmailPassword());
 
@@ -255,8 +258,10 @@ bool GMailWalletManager::getKConfig()
 
 void GMailWalletManager::clearPassword()
 {
-	kdDebug() << k_funcinfo << endl;
+	kDebug() << k_funcinfo;
 
 	mPassword.fill('0');
 	mPassword = "";
 }
+
+#include "gmailwalletmanager.moc"
