@@ -18,17 +18,20 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#ifndef KCHECKGMAIL_APP_H
+#define KCHECKGMAIL_APP_H
+
 #include <kuniqueapplication.h>
 
-class KCheckGmailTray;
 
 class KCheckGmailApp : public KUniqueApplication {
 	Q_OBJECT
 
-	public:
-		KCheckGmailApp();
-		int newInstance();
+public:
+	KCheckGmailApp();
+	int newInstance();
 
-	private:
-		KCheckGmailTray *mTray;
+private:
 };
+
+#endif // KCHECKGMAIL_APP_H
