@@ -33,52 +33,55 @@
 #include "config.h"
 
 static const char kcheckgmailVersion[] = VERSION;
-static const KCmdLineOptions gOptions[] =
-{
-	{ "legal", I18N_NOOP("Display legal information"), 0 },
-	KCmdLineLastOption
-};
 
 int main(int argc, char **argv)
 {
 	KAboutData about("kcheckgmail",
-		I18N_NOOP("KCheckGMail"), 
+		0,
+		ki18n("KCheckGMail"),
 		kcheckgmailVersion, 
-		I18N_NOOP(
+		ki18n(
 		"System tray application to display how many\nnew email "
 		"messages you have in your Gmail account."),
 		KAboutData::License_GPL, 
-		"(C) 2004 Matthew Wlazlo\n(C) 2007 Raphael Geissert\n(C) 2007 Luis Pereira", 
-		0, // text
+		ki18n("(C) 2004 Matthew Wlazlo\n(C) 2007 Raphael Geissert\n(C) 2007 Luís Pereira"),
+		KLocalizedString(), // text
 		"http://kcheckgmail.sf.net",
 		"kcheckgmail-development@lists.sourceforge.net");
+
+	// needed to get org.kcheckgmail.kcheckgmail used for D-BUS
+	about.setOrganizationDomain("kcheckgmail.org");
 	
-	about.addAuthor("Matthew Wlazlo", I18N_NOOP("Original author"), "mwlazlo@gmail.com");
-	about.addAuthor("Raphael Geissert", I18N_NOOP("Maintainer"), "atomo64@gmail.com");
-	about.addAuthor("Luis Pereira", I18N_NOOP("Developer"), "luis.artur.pereira@gmail.com");
-	about.addCredit(I18N_NOOP("Everybody who helped testing and translating KCheckGMail"), 0, 0, 0);
+	about.addAuthor(ki18n("Matthew Wlazlo"), ki18n("Original author"), "mwlazlo@gmail.com");
+	about.addAuthor(ki18n("Raphael Geissert"), ki18n("Maintainer"), "atomo64@gmail.com");
+	about.addAuthor(ki18n("Luís Pereira"), ki18n("Developer"), "luis.artur.pereira@gmail.com", "http://kcheckgmail-lpereira.blogspot.com");
+	about.addCredit(ki18n("Everybody who helped testing and translating KCheckGMail"));
 
 
-        KGlobal::locale()->setMainCatalogue("kcheckgmail");
+	KGlobal::locale()->setMainCatalog("kcheckgmail");
 
-        KCmdLineArgs::init(argc, argv, &about);
-        KCmdLineArgs::addCmdLineOptions(gOptions);
-        KUniqueApplication::addCmdLineOptions();
+	KCmdLineArgs::init(argc, argv, &about);
+	KCmdLineOptions options;
+
+	options.add("legal", ki18n("Display legal information"));
+	KCmdLineArgs::addCmdLineOptions(options);
+	KUniqueApplication::addCmdLineOptions();
 	
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 	
 	if(args->isSet("legal")) {
-		std::cout << (i18n("Legal Information:\nGoogle, Gmail and Google Mail are registered trademarks of Google Inc.\nKCheckGMail nor its authors are in any way affiliated nor endorsed by Google Inc.") + "\n");
+		std::cout << i18n("Legal Information:\nGoogle, Gmail and Google Mail are registered trademarks of Google Inc.\nKCheckGMail nor its authors are in any way affiliated nor endorsed by Google Inc.").toLocal8Bit().data() << std::endl;
 		return EXIT_SUCCESS;
 	}
 	
 	if (!KUniqueApplication::start()) {
 		KStartupInfo::handleAutoAppStartedSending();
-		std::cerr << i18n("KCheckGMail is already running!\n");
+		std::cerr << i18n("KCheckGMail is already running!\n").toLocal8Bit().data() << std::endl;
 		return EXIT_SUCCESS;
 	}
 	
 	KCheckGmailApp app;
+	app.setQuitOnLastWindowClosed(false);
 
-        return app.exec();
+	return app.exec();
 }
